<?php
/**
 * Template part for displaying post theme functions
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package WordPress
 * @subpackage Strike
 * @since Strike 1.0
 */

/**************************************************************************************************************
 * Loads google fonts to the theme
 * Thanks to themeshaper.com
 ***********************************************************************************************************/

if ( ! function_exists( 'strike_blog_fonts_url' ) ) :

function strike_blog_fonts_url() {
  $strike_blog_fonts_url   = '';
  $strike_one         = _x( 'on', 'Libre Baskerville font: on or off', 'strike-blog' );
  $strike_two         = _x( 'on', 'Rubik font: on or off', 'strike-blog' );

  if ( 'off' !== $strike_one || 'off' !== $strike_two ) {
    $strike_font_families = array();

    if ( 'off' !== $strike_one ) {
      $strike_font_families[] = 'Libre Baskerville:wght@400;700';
    }

    if ( 'off' !== $strike_two ) {
      $strike_font_families[] = 'Rubik:wght@300;400;800';
    }
  }

  $strike_query_args = array(
    'family' => urlencode( implode( '|', $strike_font_families ) ),
    'subset' => urlencode( 'cyrillic-ext,cyrillic,vietnamese,latin-ext,latin' )
  );

  $strike_blog_fonts_url = add_query_arg( $strike_query_args, 'https://fonts.googleapis.com/css' );

  return esc_url_raw( $strike_blog_fonts_url );
}

endif;


/*********************************************************************************************************
 *  Adds a span tag with dropdown icon after the unordered list
 *  that has a sub menu on the mobile menu.
 ********************************************************************************************************/

class Strike_Blog_Dropdown_Toggle_Walker_Nav_Menu extends Walker_Nav_Menu {
    function start_lvl( &$strike_output, $strike_depth = 0, $strike_args = array() ) {
        $strike_indent = str_repeat( "\t", $strike_depth );
        if( 'header_menu' == $strike_args->theme_location ) {
            $strike_output .='<div class="submenu-toggle"><a href="#"><i class="icofont-rounded-down"></i></a></div>';
        }
        $strike_output .= "\n$strike_indent<ul class=\"sub-menu\">\n";
    }
}

/****************************************************************************
 *  Custom Excerpt Length
 ****************************************************************************/

function strike_blog_excerpt( $limit ) {
  $excerpt = explode(' ', get_the_excerpt(), $limit);

  if (count($excerpt) >= $limit) {
      array_pop($excerpt);
      $excerpt = implode(" ", $excerpt) . '...';
  } else {
      $excerpt = implode(" ", $excerpt);
  }

  $excerpt = preg_replace('`\[[^\]]*\]`', '', $excerpt);

  return $excerpt;
}
/*********************************************************************************************************
 * Estimated reading time
 *********************************************************************************************************/

/* Word read count */
function strike_blog_post_read_time( $post_id ) {

      // get the post content
      $content = get_post_field( 'post_content', $post_id );

      // count the words
      $word_count = str_word_count( strip_tags( $content ) );

      // reading time itself
      $readingtime = ceil($word_count / 200);

      if ($readingtime == 1) {
       $timer = " Minute read";
      } else {
       $timer = " Minutes read"; // or your version :) I use the same wordings for 1 minute of reading or more
      }

      // I'm going to print 'X minute read' above my post
      $totalreadingtime = $readingtime . $timer;
      echo esc_html( $totalreadingtime, 'strike-blog' );
}


/*********************************************************************************************************
 * Pagination
 *********************************************************************************************************/

function strike_blog_number_pagination() {
  global $wp_query;
  $big = 9999999; // need an unlikely integer
    echo paginate_links( array(
     'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
     'format' => '?paged=%#%',
     'current' => max( 1, get_query_var('paged') ),
     'prev_next'    => true,
     'prev_text'    => __( '&#8203;', 'strike-blog' ),
     'next_text'    => __( '&#8203;', 'strike-blog' ),
     'add_args'     => false,
     'total' => $wp_query->max_num_pages) );
  }


/****************************************************************************
 *  Adds Category Color Picker Field
 ****************************************************************************/
/* Add new colorpicker field to "Add new Category" screen */
function strike_blog_colorpicker_field_add_new_category( $taxonomy ) {
  ?>
    <div class="form-field term-colorpicker-wrap">
        <label for="term-colorpicker"><?php echo esc_html_e( 'Select Category Color', 'strike-blog' ); ?></label>
        <input name="_category_color" value="#ffffff" class="colorpicker" id="term-colorpicker" />
        <p><?php esc_html_e( 'Select Specific color for this category','strike-blog' ); ?></p>
    </div>
  <?php
}
add_action( 'category_add_form_fields', 'strike_blog_colorpicker_field_add_new_category' );

/* Add new colopicker field to "Edit Category" screen */
function strike_blog_colorpicker_field_edit_category( $term ) {
    $color = get_term_meta( $term->term_id, '_category_color', true );
    $color = ( ! empty( $color ) ) ? "#{$color}" : '#f6727f';
  ?>
    <tr class="form-field term-colorpicker-wrap">
        <th scope="row"><label for="term-colorpicker"><?php echo esc_html_e( 'Select Category Color', 'strike-blog' ); ?></label></th>
        <td>
            <input name="_category_color" value="<?php echo esc_attr( $color ); ?>" class="colorpicker" id="term-colorpicker" />
            <p class="description"><?php esc_html_e( 'Select Specific color for this category','strike-blog' ); ?></p>
        </td>
    </tr>
  <?php
}
add_action( 'category_edit_form_fields', 'strike_blog_colorpicker_field_edit_category' );   // Variable Hook Name

/* Term Metadata - Save Created and Edited Term Metadata */
function strike_blog_save_termmeta( $term_id ) {

    // Save term color if possible
    if( isset( $_POST['_category_color'] ) && ! empty( $_POST['_category_color'] ) ) {
        $cat_color = sanitize_text_field( wp_unslash( $_POST['_category_color'] ) );
        update_term_meta( $term_id, '_category_color', sanitize_hex_color_no_hash( $cat_color ) );
    } else {
        delete_term_meta( $term_id, '_category_color' );
    }

}
add_action( 'created_category', 'strike_blog_save_termmeta' );  // Variable Hook Name
add_action( 'edited_category',  'strike_blog_save_termmeta' );  // Variable Hook Name


/* Enqueue wp-color-picker */
function strike_blog_category_colorpicker_enqueue( $taxonomy ) {
    // Colorpicker Scripts
    wp_enqueue_script( 'wp-color-picker' );

    // Colorpicker Styles
    wp_enqueue_style( 'wp-color-picker' );

}
add_action( 'admin_enqueue_scripts', 'strike_blog_category_colorpicker_enqueue' );

/* Add Display Color Picker */
function strike_blog_the_category_colors() {

  $categories = get_the_category();

  $separator = '';
  $output = '';
  if($categories){
  ?>
  <div class="ct-categories">
  <?php
      foreach( $categories as $category ) {
          $color = get_term_meta( $category->term_id, '_category_color', true );
          $color = ( ! empty( $color ) ) ? "#{$color}" : '#f6727f';

          /* translators: %s: Category name */
          $output .= '<span class="ct-category" style="background-color: '.  $color . '; "><a href="'.esc_url( get_category_link($category->term_id ) ).'" title="' . esc_attr( sprintf( __( "View all posts in %s", 'strike-blog' ), $category->name ) ) . '">'.$category->cat_name.'</a></span>'.$separator;
      }
      echo trim( $output, $separator );
  ?>
  </div>
  <?php
  }
}

/****************************************************************************
 *  Multi Select  Categories
 ****************************************************************************/

/**
 * Multiselect option for WP Customizer
 *
 * @param $wp_customize
 */
add_action( 'customize_register', __NAMESPACE__ . '\\strike_blog_multiselect_customize_register' );
function strike_blog_multiselect_customize_register( $wp_customize ) {
	/**
	 * Multiple select customize control class.
	 */
	class Strike_Blog__Customize_Control_Multiple_Select extends \WP_Customize_Control {

		/**
		 * The type of customize control being rendered.
		 */
		public $type = 'multiple-select';

		/**
		 * Displays the multiple select on the customize screen.
		 */
		public function render_content() {

			if ( empty( $this->choices ) ) {
				return;
			}
			?>
            <label>
                <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
                <select <?php $this->link(); ?> multiple="multiple" style="height: 100%;">
					<?php
					foreach ( $this->choices as $value => $label ) {
						$selected = ( in_array( $value, $this->value() ) ) ? selected( 1, 1, false ) : '';
						echo '<option value="' . esc_attr( $value ) . '"' . $selected . '>' . $label . '</option>';
					}
					?>
                </select>
            </label>
		<?php }
	}
}

/**
 * Get all categories
 * 
 * @return array
 */
function strike_blog_project_types() {
	$cats    = array();
	$cats[0] = __( 'Filter by Latest Posts', 'strike-blog' );
	foreach ( get_categories() as $categories => $category ) {
		$cats[ $category->term_id ] = $category->name;
	}

	return $cats;
}

/**
 * Validate the options against the existing categories
 *
 * @param  string[] $input
 *
 * @return string
 */
function strike_blog_project_types_sanitize( $input ) {
	$valid = strike_blog_project_types();

	foreach ( $input as $value ) {
		if ( ! array_key_exists( $value, $valid ) ) {
			return [];
		}
	}

	return $input;
}


/*****************************************************************************
* Notice: Premium Version
*****************************************************************************/
/* Setup Transients after theme activation */
if ( ! function_exists( 'strike_blog_theme_setup' ) ) :

  function strike_blog_after_activation() {
    // Add Notification Options and Transients
    set_transient( 'ct-times-shown-transient', 1, 43200 ); // 12 hours in seconds
    add_option( 'dismissed-ct_premium', 'unset' );
  }
  
  endif;
  add_action( 'after_switch_theme', 'strike_blog_after_activation' );
  
  /**
   * AJAX handler to store the state of dismissible notices.
   */
  add_action( 'wp_ajax_ct_premium_notice_handler', 'strike_blog_premium_ajax_notice_handler' );
  function strike_blog_premium_ajax_notice_handler() {
      if ( isset( $_POST['type'] ) ) {
          // Pick up the notice "type" - passed via jQuery (the "data-notice" attribute on the notice)
          $type = sanitize_text_field( wp_unslash( $_POST['type'] ) );
          // Store it in the options table
          update_option( 'dismissed-' . $type, 'set' );
      }
  }
  
  // Actual Notice
  function strike_blog_premium_admin_notice() {
      $theme = wp_get_theme();
      $theme_name = esc_html( $theme->get( 'Name' ) );
      $theme_slug = esc_html( $theme->get( 'TextDomain' ) );
  
      // Check if it's been dismissed...
      if ( !get_transient( 'ct-times-shown-transient' ) ) {
          // Added the class "notice-get-started-class" so jQuery pick it up and pass via AJAX,
          // and added "data-notice" attribute in order to track multiple / different notices
          // multiple dismissible notice states
          if ( get_option( 'dismissed-ct_premium' ) == 'unset' ) {
          ?>
          <div class="updated notice notice-ct-premium-class is-dismissible" data-notice="ct_premium">
              <div class="crafthemes-ct-premium-notice clearfix">
                  <h2><?php printf( esc_html__( 'UPGRADE to %1$s Pro and unlock all the PREMIUM Features!', 'strike-blog' ), esc_html( $theme_name ) ); ?></h2>
                  <p><?php _e( 'Get the best out of your blog with Periar Pro! Strike Blog Pro offers Intro Header, <b>Dark Mode Feature</b>,Customizable typography, Optimized SEO and many more fearures. You will also get Premium support for your theme.', 'periar' ); ?></p>
                  <div class="ct-action-buttons">
                      <a href="<?php echo esc_url( "https://www.crafthemes.com/theme/". $theme_slug . "-pro/"); ?>" target="_blank"><button id="buy-pro-btn" type="button" class="button button-primary"><?php esc_html_e( 'Upgrade to Pro!', 'strike-blog' ); ?></button></a>
                      <strong><a class="left-margin-compare" href="https://www.crafthemes-demo.live/strike-blog-premium-two/"><?php esc_html_e( 'Live Demo', 'periar' ); ?></a></strong>
                  </div>
              </div><!-- /.ct-theme-notice-content -->
          </div>
      <?php } }
  }
  
  add_action( 'admin_notices', 'strike_blog_premium_admin_notice' );
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  